@@ -1,9 +1,9 @@
 ;;; which-key-tests.el --- Tests for which-key.el -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2015 Justin Burkett
+;; Copyright (C) 2017  Free Software Foundation, Inc.
 
 ;; Author: Justin Burkett <justin@burkett.cc>
-;; URL: https://github.com/justbur/emacs-which-key
+;; Maintainer: Justin Burkett <justin@burkett.cc>
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -99,7 +99,7 @@
              '("SPC t 2" . "[ ] test mode")))))
 
 (ert-deftest which-key-test--maybe-replace-multiple ()
-  "Test `which-key-allow-multiple-replacements'. See #156"
+  "Test `which-key-allow-multiple-replacements'. See #156."
   (let ((which-key-replacement-alist
          '(((nil . "helm") . (nil . "HLM"))
            ((nil . "projectile") . (nil . "PRJTL"))))
@@ -114,5 +114,13 @@
              (which-key--maybe-replace '("C-c C-c" . "helm-projectile-x"))
              '("C-c C-c" . "HLM-PRJTL-x")))))
 
+(ert-deftest which-key-test--key-extraction ()
+  "Test `which-key--extract-key'. See #161."
+  (should (equal (which-key--extract-key "SPC a") "a"))
+  (should (equal (which-key--extract-key "C-x a") "a"))
+  (should (equal (which-key--extract-key "<left> b a") "a"))
+  (should (equal (which-key--extract-key "<left> a .. c") "a .. c"))
+  (should (equal (which-key--extract-key "M-a a .. c") "a .. c")))
+
 (provide 'which-key-tests)
 ;;; which-key-tests.el ends here
